#[repr(transparent)]pub struct Secp256k1RecoverableSignature(pub [u8; 65]);Expand description
Recoverable 65-byte secp256k1 signature, i.e. 64-byte signature with additional recovery byte
Tuple Fields
0: [u8; 65]Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for Secp256k1RecoverableSignature
impl<'arbitrary> Arbitrary<'arbitrary> for Secp256k1RecoverableSignature
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl AsRef<[u8]> for Secp256k1RecoverableSignature
impl AsRef<[u8]> for Secp256k1RecoverableSignature
Sourceimpl BorshDeserialize for Secp256k1RecoverableSignature
impl BorshDeserialize for Secp256k1RecoverableSignature
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for Secp256k1RecoverableSignature
impl BorshSchema for Secp256k1RecoverableSignature
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for Secp256k1RecoverableSignature
impl BorshSerialize for Secp256k1RecoverableSignature
Sourceimpl Clone for Secp256k1RecoverableSignature
impl Clone for Secp256k1RecoverableSignature
Sourcefn clone(&self) -> Secp256k1RecoverableSignature
fn clone(&self) -> Secp256k1RecoverableSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for Secp256k1RecoverableSignature
impl<'de> Deserialize<'de> for Secp256k1RecoverableSignature
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'__derive_more_into> From<&'__derive_more_into Secp256k1RecoverableSignature> for &'__derive_more_into [u8; 65]
impl<'__derive_more_into> From<&'__derive_more_into Secp256k1RecoverableSignature> for &'__derive_more_into [u8; 65]
Sourcefn from(value: &'__derive_more_into Secp256k1RecoverableSignature) -> Self
fn from(value: &'__derive_more_into Secp256k1RecoverableSignature) -> Self
Converts to this type from the input type.
Sourceimpl From<(&Signature<Secp256k1>, RecoveryId)> for Secp256k1RecoverableSignature
impl From<(&Signature<Secp256k1>, RecoveryId)> for Secp256k1RecoverableSignature
Sourceimpl From<(Signature<Secp256k1>, RecoveryId)> for Secp256k1RecoverableSignature
impl From<(Signature<Secp256k1>, RecoveryId)> for Secp256k1RecoverableSignature
Sourceimpl From<Secp256k1RecoverableSignature> for [u8; 65]
impl From<Secp256k1RecoverableSignature> for [u8; 65]
Sourcefn from(value: Secp256k1RecoverableSignature) -> Self
fn from(value: Secp256k1RecoverableSignature) -> Self
Converts to this type from the input type.
Sourceimpl Hash for Secp256k1RecoverableSignature
impl Hash for Secp256k1RecoverableSignature
Sourceimpl JsonSchema for Secp256k1RecoverableSignature
impl JsonSchema for Secp256k1RecoverableSignature
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Secp256k1RecoverableSignature
impl Ord for Secp256k1RecoverableSignature
Sourcefn cmp(&self, other: &Secp256k1RecoverableSignature) -> Ordering
fn cmp(&self, other: &Secp256k1RecoverableSignature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Secp256k1RecoverableSignature
impl PartialEq for Secp256k1RecoverableSignature
Sourcefn eq(&self, other: &Secp256k1RecoverableSignature) -> bool
fn eq(&self, other: &Secp256k1RecoverableSignature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for Secp256k1RecoverableSignature
impl PartialOrd for Secp256k1RecoverableSignature
Sourceimpl Serialize for Secp256k1RecoverableSignaturewhere
Self: Display,
impl Serialize for Secp256k1RecoverableSignaturewhere
Self: Display,
Sourceimpl TryFrom<&Secp256k1RecoverableSignature> for (Signature, RecoveryId)
impl TryFrom<&Secp256k1RecoverableSignature> for (Signature, RecoveryId)
Sourceimpl TryFrom<&Secp256k1RecoverableSignature> for Signature
impl TryFrom<&Secp256k1RecoverableSignature> for Signature
Sourceimpl TryFrom<Secp256k1RecoverableSignature> for (Signature, RecoveryId)
impl TryFrom<Secp256k1RecoverableSignature> for (Signature, RecoveryId)
Sourceimpl TryFrom<Secp256k1RecoverableSignature> for Signature
impl TryFrom<Secp256k1RecoverableSignature> for Signature
impl Copy for Secp256k1RecoverableSignature
impl Eq for Secp256k1RecoverableSignature
impl StructuralPartialEq for Secp256k1RecoverableSignature